Struct ZwpIdleInhibitManagerV1
pub struct ZwpIdleInhibitManagerV1 { /* private fields */ }wayland and Linux only.Expand description
control behavior when display idles
This interface permits inhibiting the idle behavior such as screen blanking, locking, and screensaving. The client binds the idle manager globally, then creates idle-inhibitor objects for each surface.
Warning! The protocol described in this file is experimental and backward incompatible changes may be made. Backward compatible changes may be added together with the corresponding interface version bump. Backward incompatible changes are done by bumping the version number in the protocol and interface names and resetting the interface version. Once the protocol is to be declared stable, the ‘z’ prefix and the version number in the protocol and interface names are removed and the interface version number is reset.
This interface has no events.
Implementations
impl ZwpIdleInhibitManagerV1
impl ZwpIdleInhibitManagerV1
pub fn destroy(&self)
pub fn destroy(&self)
destroy the idle inhibitor object
Destroy the inhibit manager.
pub fn create_inhibitor<U, D>(
&self,
surface: &WlSurface,
qh: &QueueHandle<D>,
udata: U,
) -> ZwpIdleInhibitorV1
pub fn create_inhibitor<U, D>( &self, surface: &WlSurface, qh: &QueueHandle<D>, udata: U, ) -> ZwpIdleInhibitorV1
create a new inhibitor object
Create a new inhibitor object associated with the given surface.